# frozen_string_literal: true

module Jekyll
  module Filters
    # Liquid filter for use in templates
    module Thumbnail
      @@cached_images = {}

      # Generates a thumbnail and returns its alternate destination
      def thumbnail(input, width = nil, height = nil, crop = nil, auto_rotate = nil)
        return unless input

        image = cached_image input
        thumb = image.thumbnail(width: width,
                                height: height,
                                crop: crop,
                                auto_rotate: auto_rotate)

        thumb.write && thumb.optimize

        thumb.dest
      rescue Vips::Error => e
        Jekyll.logger.warn "Failed to process #{input}: #{e.message}"
        input
      end

      private

      def cached_image?(input)
        @@cached_images.key? input
      end

      def cached_image(input)
        @@cached_images[input] ||= Jekyll::Images::Image.new(@context.registers[:site], input)
      end
    end
  end
end

Liquid::Template.register_filter(Jekyll::Filters::Thumbnail)
